@@ -1087,8 +1087,6 @@ class GlobalChem(object):
 
         for node_key, node_value in self.__NODES__.items():
 
-            definition = {}
-
             if node_key == 'global_chem' or node_key == 'common_regex_patterns':
                 continue
 
@@ -1098,6 +1096,8 @@ class GlobalChem(object):
 
             for name, smiles in names.items():
 
+                definition = {}
+
                 # Sanitize the Node Key
 
                 name = name.lower()
@@ -1108,7 +1108,7 @@ class GlobalChem(object):
                 if 0 <= distance <= distance_tolerance:
 
                     definition[name] = smiles
-                    definition['network_path'] = network_path[-1]
+                    definition['network_path'] = network_path
                     definition['levenshtein_distance'] = distance
 
                     if distance == 0:
